@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,20 +20,19 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.metastore_v1beta.services.dataproc_metastore import pagers
 from google.cloud.metastore_v1beta.types import metastore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
 from .client import DataprocMetastoreClient
@@ -82,31 +79,26 @@ class DataprocMetastoreAsyncClient:
     parse_network_path = staticmethod(DataprocMetastoreClient.parse_network_path)
     service_path = staticmethod(DataprocMetastoreClient.service_path)
     parse_service_path = staticmethod(DataprocMetastoreClient.parse_service_path)
-
     common_billing_account_path = staticmethod(
         DataprocMetastoreClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         DataprocMetastoreClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(DataprocMetastoreClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         DataprocMetastoreClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         DataprocMetastoreClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         DataprocMetastoreClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(DataprocMetastoreClient.common_project_path)
     parse_common_project_path = staticmethod(
         DataprocMetastoreClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(DataprocMetastoreClient.common_location_path)
     parse_common_location_path = staticmethod(
         DataprocMetastoreClient.parse_common_location_path
@@ -114,7 +106,8 @@ class DataprocMetastoreAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -129,7 +122,7 @@ class DataprocMetastoreAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -146,7 +139,7 @@ class DataprocMetastoreAsyncClient:
 
     @property
     def transport(self) -> DataprocMetastoreTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             DataprocMetastoreTransport: The transport used by the client instance.
@@ -160,12 +153,12 @@ class DataprocMetastoreAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, DataprocMetastoreTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the dataproc metastore client.
+        """Instantiates the dataproc metastore client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -197,7 +190,6 @@ class DataprocMetastoreAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = DataprocMetastoreClient(
             credentials=credentials,
             transport=transport,
@@ -229,7 +221,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -239,7 +230,7 @@ class DataprocMetastoreAsyncClient:
         Returns:
             google.cloud.metastore_v1beta.services.dataproc_metastore.pagers.ListServicesAsyncPager:
                 Response message for
-                [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
+                   [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -259,7 +250,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -313,7 +303,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -340,7 +329,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -415,7 +403,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``service_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -445,7 +432,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if service is not None:
@@ -486,7 +472,7 @@ class DataprocMetastoreAsyncClient:
         request: metastore.UpdateServiceRequest = None,
         *,
         service: metastore.Service = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -518,7 +504,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -548,7 +533,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if service is not None:
             request.service = service
         if update_mask is not None:
@@ -608,7 +592,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -648,7 +631,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -673,7 +655,7 @@ class DataprocMetastoreAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=metastore.OperationMetadata,
         )
 
@@ -704,7 +686,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -714,7 +695,7 @@ class DataprocMetastoreAsyncClient:
         Returns:
             google.cloud.metastore_v1beta.services.dataproc_metastore.pagers.ListMetadataImportsAsyncPager:
                 Response message for
-                [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
+                   [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -734,7 +715,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -788,7 +768,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -815,7 +794,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -889,7 +867,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``metadata_import_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -919,7 +896,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if metadata_import is not None:
@@ -960,7 +936,7 @@ class DataprocMetastoreAsyncClient:
         request: metastore.UpdateMetadataImportRequest = None,
         *,
         metadata_import: metastore.MetadataImport = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -994,7 +970,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1024,7 +999,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if metadata_import is not None:
             request.metadata_import = metadata_import
         if update_mask is not None:
@@ -1074,7 +1048,6 @@ class DataprocMetastoreAsyncClient:
             request (:class:`google.cloud.metastore_v1beta.types.ExportMetadataRequest`):
                 The request object. Request message for
                 [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1beta.DataprocMetastore.ExportMetadata].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1091,7 +1064,6 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = metastore.ExportMetadataRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1156,7 +1128,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``backup`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1186,7 +1157,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if service is not None:
             request.service = service
         if backup is not None:
@@ -1244,7 +1214,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1254,7 +1223,7 @@ class DataprocMetastoreAsyncClient:
         Returns:
             google.cloud.metastore_v1beta.services.dataproc_metastore.pagers.ListBackupsAsyncPager:
                 Response message for
-                [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
+                   [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1274,7 +1243,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -1328,7 +1296,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1353,7 +1320,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -1424,7 +1390,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``backup_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1454,7 +1419,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if backup is not None:
@@ -1514,7 +1478,6 @@ class DataprocMetastoreAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1554,7 +1517,6 @@ class DataprocMetastoreAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -1579,7 +1541,7 @@ class DataprocMetastoreAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=metastore.OperationMetadata,
         )
 
